@@ -83,3 +83,8 @@ create index on minion_jobs using gin (notes);
 
 -- 20 up
 alter table minion_workers set unlogged;
+
+-- 21 up
+alter table minion_jobs add column sequence text;
+alter table minion_jobs add column next bigint unique;
+create index on minion_jobs (sequence, next);
